/*
Script: peeradd.js
    The client-side javascript code for the peeradd plugin.
Copyright:
    Copyright (C) 2016-2019 Noam <noamgit@gmail.com>
    https://github.com/noam09
    Much credit to:
    (C) Innocenty Enikeew 2011 <enikesha@gmail.com>
    https://bitbucket.org/enikesha/deluge-xmppnotify
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 3, or (at your option)
    any later version.
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    You should have received a copy of the GNU General Public License
    along with this program.  If not, write to:
        The Free Software Foundation, Inc.,
        51 Franklin Street, Fifth Floor
        Boston, MA  02110-1301, USA.
    In addition, as a special exception, the copyright holders give
    permission to link the code of portions of this program with the OpenSSL
    library.
    You must obey the GNU General Public License in all respects for all of
    the code used other than OpenSSL. If you modify file(s) with this
    exception, you may extend this exception to your version of the file(s),
    but you are not obligated to do so. If you do not wish to do so, delete
    this exception statement from your version. If you delete this exception
    statement from all source files in the program, then also delete it here.
*/

peeraddPanel = Ext.extend(Ext.form.FormPanel, {
    constructor: function(config) {
        config = Ext.apply({
            border: false,
            title: _("peeradd"),
            autoHeight: true,
        }, config);
        peeraddPanel.superclass.constructor.call(this, config);
    },
    initComponent: function() {
        peeraddPanel.superclass.initComponent.call(this);
        this.opts = new Deluge.OptionsManager();

        var fieldset = this.add({
            xtype: 'fieldset',
            title: _('peeradd settings'),
            autoHeight: true,
            autoWidth: true,
            defaultType: 'textfield'
        });
        this.opts.bind('peers', fieldset.add({
            fieldLabel: _('peers'),
            anchor:'100%',
            name: 'peers',
            autoWidth: true,
            value: ''
        }));

        deluge.preferences.on('show', this.onPreferencesShow, this);
    },

    onPreferencesShow: function () {
        deluge.client.peeradd.get_config({
            success: function (config) {
            if (!Ext.isEmpty(config['peers'])) {
                config['peers'] = config['peers'];
            }
           
            //Ext.getCmp("mycheck").checked;
            this.opts.set(config);
            },
            scope: this,
        });
    },
    onApply: function(e) {
        var changed = this.opts.getDirty();
        if (!Ext.isObjectEmpty(changed)) {
            if (!Ext.isEmpty(changed['peers'])) {
            changed['peers'] = changed['peers'];
            }
           
            deluge.client.peeradd.set_config(changed, {
                success: this.onSetConfig,
                scope: this,
            });
        }
    },
    onSetConfig: function() {
        this.opts.commit();
    },
});


peeraddPlugin = Ext.extend(Deluge.Plugin, {
    name: "peeradd",

    onDisable: function() {
        deluge.preferences.removePage(this.prefsPage);
    },

    onEnable: function() {
        this.prefsPage = new peeraddPanel();
        this.prefsPage = deluge.preferences.addPage(this.prefsPage);
    }
});

Deluge.registerPlugin('peeradd', peeraddPlugin);
